@@ -1,4 +1,4 @@
-from constant import TradeType
+from .constant import TradeType
 
 
 def parse_symbol(symbol: str) -> (str, str):
